# -*- coding: utf-8 -*-
"""
..
    SmartHTTP 
    Release 0.5 rev. 279 on 2010-07-20 04:32:27.374371
    Copyright (C) 2009-2010,
    Authors: Dan Kluev <dan@kluev.name>

    Module smarthttp.sites.blogs
    Blogs site-handlers
    Last changed on 2010-05-16 12:59:57+11:00 rev. 186:94102a16ee7e by Dan Kluev <orion@ssorion.info>

..
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.


Blogs site-handlers
===================

.. _smarthttp.sites.blogs-BlogSite:

:class:`BlogSite`
-----------------



.. autoclass:: BlogSite
    :members:
    :undoc-members:

"""
__docformat__ = 'restructuredtext'
from .. import *

class BlogSite(object):
    pass

